#include <WiFi.h>
#include <WebServer.h>
#include <LITTLEFS.h>
#include <DHT.h>

IPAddress local_IP(192,168,4,2);
IPAddress gateway(192,168,4,1);
IPAddress subnet(255,255,252,0);
int WiFi_OK;
int WiFi_Mode = 1;
int EtatLED = 1;
WebServer server(80);
String Page;
DHT dht_12_DHT11(12,DHT11);

// Décrire cette fonction
void FonctionURLNotFound() {
  handleFileRead(server.uri());
}

String getContentType(String filename) 
{ // convert the file extension to the MIME type
  if (filename.endsWith(".html")) return "text/html";
  else if (filename.endsWith(".css")) return "text/css";
  else if (filename.endsWith(".js")) return "application/javascript";
  else if (filename.endsWith(".ico")) return "image/x-icon";
  return "text/plain";
}

bool handleFileRead(String path)
{ // send the right file to the client (if it exists)
 //Serial.println("handleFileRead: " + path);
 if (path.endsWith("/")) path += "index.html";         // If a folder is requested, send the index file
  String contentType = getContentType(path);            // Get the MIME type
  Serial.print("handleFileRead file: "); Serial.println(path);
  const char *Name = path.c_str();
  File file = LITTLEFS.open(Name);
  if(!file || file.isDirectory()){
      Serial.print("- failed to open file for reading"); Serial.println(Name);
      return false;
  }
  size_t sent = server.streamFile(file, contentType); // And send it to the client
  file.close();                                       // Then close the file again
  return true;
}

void ReadTemp()
{
  handleFileRead("/FancyThermoJSON.html");
}

// Décrire cette fonction
void MakeJSON() {
  String JSONData = "{ \"Temp\": " + String(23.4) + ",  \"Hum\": " + String(45.6) + "}\n";//
  //String JSONData = "{ \"Temp\": " + String(dht_12_DHT11.readTemperature()) + ",  \"Hum\": " + String(dht_12_DHT11.readHumidity()) + "}\n";
  Serial.print("JSON Data ="); Serial.print(JSONData);
  server.send(200, "data/json", JSONData);
}


void listDir(fs::FS &fs, const char * dirname, uint8_t levels){
    Serial.printf("Listing directory: %s\r\n", dirname);

    File root = fs.open(dirname);
    if(!root){
        Serial.println("- failed to open directory");
        return;
    }
    if(!root.isDirectory()){
        Serial.println(" - not a directory");
        return;
    }

    File file = root.openNextFile();
    while(file){
        if(file.isDirectory()){
            Serial.print("  DIR : ");
            Serial.println(file.name());
            if(levels){
                listDir(fs, file.name(), levels -1);
            }
        } else {
            Serial.print("  FILE: ");
            Serial.print(file.name());
            Serial.print("\tSIZE: ");
            Serial.println(file.size());
        }
        file = root.openNextFile();
    }
}


void setup() {
  Serial.begin(115200);
  pinMode(LED_BUILTIN, OUTPUT);
    Serial.println("\n[*] Creating AP");
    WiFi.mode(WIFI_AP);
    WiFi.softAP("ESP32_AP");
    Serial.print("[+] AP Created with IP Gateway ");
    Serial.println(WiFi.softAPIP());
    
  if(!LITTLEFS.begin()) {
  Serial.println("An Error has occurred while mounting LittleFS");
  return;
  }
  Serial.println("LittleFS Ready");

    EtatLED = 0;
  Page = "";
  Serial.println("Démarrage");
  digitalWrite(LED_BUILTIN, HIGH);
  delay(1000);
  digitalWrite(LED_BUILTIN, LOW);
  listDir(LITTLEFS, "/", 3);

  dht_12_DHT11.begin();
  server.on("/", ReadTemp);
  server.on("/DataTemp.json", MakeJSON);
  server.onNotFound(FonctionURLNotFound);
  server.begin();
  EtatLED = 1;
  pinMode(2, OUTPUT);
  digitalWrite(2, EtatLED);
  Serial.println("Thermomètre prêt");
}

void loop() {
  server.handleClient();

}
